==> e_filetypes_py-1.1.0.tar.gz: e_filetypes_py-1.1.0/README.md <==
<div align="center">
    <img src="https://github.com/E-FileTypes/e-filetypes-py/blob/main/assets/efiletypeslogo-dark-python.png?raw=true#gh-light-mode-only" height="200">
    <img src="https://github.com/E-FileTypes/e-filetypes-py/blob/main/assets/efiletypeslogo-white-python.png?raw=true#gh-dark-mode-only" height="200">
    <h3>E-FileTypes-Py</h3>
</div>

<br/>
<br/>

| |
| :---: |
| ![Static Badge](https://img.shields.io/badge/built_using-python-blue) ![Static Badge](https://img.shields.io/badge/built%20in-only_36_hours!-purple) |
| [![Documentation Status](https://readthedocs.org/projects/e-filetypes-py/badge/?version=latest)](https://e-filetypes-py.readthedocs.io/en/latest/?badge=latest) ![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/E-FileTypes/e-filetypes-py/release-please.yml?label=release-please) ![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/E-FileTypes/e-filetypes-py/ruff.yml?label=ruff) ![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/E-FileTypes/e-filetypes-py/publish-pypi.yml?label=pypi%20package) |
| ![GitHub commit activity (branch)](https://img.shields.io/github/commit-activity/w/E-FileTypes/e-filetypes-py) ![PyPI - Version](https://img.shields.io/pypi/v/e-filetypes-py) |
| |

<br/>

## 🌟 Overview

The E-FileTypes-Py library allows you to integrate with E-FileTypes using any Python application.

## 🧩 Installation

You can install the library using pip:
```bash
pip install e-filetypes-py
```
If you would like to use a GUI, you can use the [E-FileTypes Client App](https://github.com/E-FileTypes/client-app), which is available for download on Mac, Windows, and Linux.

## 📄 Docs

You can view the Python specific docs [here](https://e-filetypes-py.readthedocs.io/en/latest/). These docs are updated on every new build of the app. These docs include a lot of info on how to use the library as well as some examples.

## 🏎️ Benchmarks

You can view the benchmarks [here](https://github.com/E-FileTypes/e-filetypes-py/blob/main/benchmarks/README.md). I highly recommend you check them out, as they are very interesting, and the improvements are very significant.

==> e_filetypes_py-2.0.1.tar.gz: e_filetypes_py-2.0.1/README.md <==
<div align="center">
    <img src="https://github.com/E-FileTypes/e-filetypes-py/blob/main/assets/efiletypeslogo-dark-python.png?raw=true#gh-light-mode-only" height="200">
    <img src="https://github.com/E-FileTypes/e-filetypes-py/blob/main/assets/efiletypeslogo-white-python.png?raw=true#gh-dark-mode-only" height="200">
    <h3>E-FileTypes-Py</h3>
</div>

<br/>
<br/>

| |
| :---: |
| ![Static Badge](https://img.shields.io/badge/built_using-python-blue) ![Static Badge](https://img.shields.io/badge/built%20in-only_36_hours!-purple) ![Static Badge](https://img.shields.io/badge/dependencies-1-gold) |
| [![Documentation Status](https://readthedocs.org/projects/e-filetypes-py/badge/?version=latest)](https://e-filetypes-py.readthedocs.io/en/latest/?badge=latest) ![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/E-FileTypes/e-filetypes-py/release-please.yml?label=release-please) ![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/E-FileTypes/e-filetypes-py/ruff.yml?label=ruff) ![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/E-FileTypes/e-filetypes-py/publish-pypi.yml?label=pypi%20package) |
| ![GitHub commit activity (branch)](https://img.shields.io/github/commit-activity/w/E-FileTypes/e-filetypes-py) ![PyPI - Version](https://img.shields.io/pypi/v/e-filetypes-py) |
| |

<br/>

## 🌟 Overview

The E-FileTypes-Py library allows you to integrate with E-FileTypes using any Python application.

## 🧩 Installation

You can install the library using pip:
```bash
pip install e-filetypes-py
```
If you would like to use a GUI, you can use the [E-FileTypes Client App](https://github.com/E-FileTypes/client-app), which is available for download on Mac, Windows, and Linux.

## 📄 Docs

You can view the Python specific docs [here](https://e-filetypes-py.readthedocs.io/en/latest/). These docs are updated on every new build of the app. These docs include a lot of info on how to use the library as well as some examples.

## 🏎️ Benchmarks

You can view the benchmarks [here](https://github.com/E-FileTypes/e-filetypes-py/blob/main/benchmarks/README.md). I highly recommend you check them out, as they are very interesting, and the improvements are very significant.
